; -------------------- getScaledSize --------------------
; Calculates the scaled size of a sprite.
;
; Version: 1.0
; Author: Badja <http://move.to/badja> <badja@alphalink.com.au>
; Date: 21 December 1999
; Size: 19 bytes
;
; Input:
;    B = height of unscaled sprite
;    C = width of unscaled sprite (in pixels)
;   HL = scale factor ($0000 to $0100 <=> 0% to 100%)
;        eg: $0080 is 50%
;
; Output:
;    A = height of scaled sprite
;    H = width of scaled sprite
;
; Destroys:
;    AF, BC, DE, HL



getScaledSize:
	bit	0,h
	jr	nz,_SSG_noScale
	ld	a,l
	ld	h,b
	call	MUL_HL_S
	ld	l,a
	ld	a,h
	ld	h,c
	call	MUL_HL_S
	ret	
_SSG_noScale:
	ld	a,b
	ld	h,c
	ret

;----------------------------------------------------------------------------
;[ MUL_HL_S ] by Hideaki Omuro
; optimized for size (13 bytes, 315-363 clocks)
;
;parameters:
; H = 8-bit multiplicand, L = 8-bit multiplier
;returns:
; HL = 16-bit product
;modifies:
; BDEFHL
;----------------------------------------------------------------------------
MUL_HL_S:
   LD    D, 0                          ; DE = multiplier, H = multiplicand
   LD    E, L
   LD    L, D                          ; result = 0

   LD    B, 8                          ; 8 loops (8 bits)

_CMH_mulloop:
   ADD   HL, HL                        ; shift/test bit
   JR    NC, _CMH_noadd                ; if shifted bit is set then
   ADD   HL, DE                        ; add the multiplier
_CMH_noadd:
   DJNZ  _CMH_mulloop

   RET 